pub struct ZwpPointerGestureSwipeV1 { /* private fields */ }Expand description
a swipe gesture object
A swipe gesture object notifies a client about a multi-finger swipe gesture detected on an indirect input device such as a touchpad. The gesture is usually initiated by multiple fingers moving in the same direction but once initiated the direction may change. The precise conditions of when such a gesture is detected are implementation-dependent.
A gesture consists of three stages: begin, update (optional) and end. There cannot be multiple simultaneous hold, pinch or swipe gestures on a same pointer/seat, how compositors prevent these situations is implementation-dependent.
A gesture may be cancelled by the compositor or the hardware. Clients should not consider performing permanent or irreversible actions until the end of a gesture has been received.
See also the Request enum for this interface.
Implementations
Sourceimpl ZwpPointerGestureSwipeV1
impl ZwpPointerGestureSwipeV1
Sourcepub fn begin(&self, serial: u32, time: u32, surface: &WlSurface, fingers: u32)
pub fn begin(&self, serial: u32, time: u32, surface: &WlSurface, fingers: u32)
multi-finger swipe begin
This event is sent when a multi-finger swipe gesture is detected on the device.
Sourcepub fn update(&self, time: u32, dx: f64, dy: f64)
pub fn update(&self, time: u32, dx: f64, dy: f64)
multi-finger swipe motion
This event is sent when a multi-finger swipe gesture changes the position of the logical center.
The dx and dy coordinates are relative coordinates of the logical center of the gesture compared to the previous event.
Sourcepub fn end(&self, serial: u32, time: u32, cancelled: i32)
pub fn end(&self, serial: u32, time: u32, cancelled: i32)
multi-finger swipe end
This event is sent when a multi-finger swipe gesture ceases to be valid. This may happen when one or more fingers are lifted or the gesture is cancelled.
When a gesture is cancelled, the client should undo state changes caused by this gesture. What causes a gesture to be cancelled is implementation-dependent.